#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 email-validate
version:              2.3.2.21
visibility:           public
id:                   email-validate-2.3.2.21-CqGjuS2PJTaBenHakzPGuf
key:                  email-validate-2.3.2.21-CqGjuS2PJTaBenHakzPGuf
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  b0e13b910b80a6a30401d19f0a52af91
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs:         /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.6.6/email-validate-2.3.2.21
hs-libraries:         HSemail-validate-2.3.2.21-CqGjuS2PJTaBenHakzPGuf
depends:
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    bytestring-0.11.5.3 template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

